:orphan:

.. _examples:

Example Gallery
---------------


.. raw:: html

    <div class="sphx-glr-thumbnails">

.. thumbnail-parent-div-open

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Imports">

.. only:: html

  .. image:: /generated/gallery/images/thumb/sphx_glr_stix_thumb.png
    :alt:

  :ref:`sphx_glr_generated_gallery_stix.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Solar Orbiter/STIX Visibility Imaging</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Create images from RHESSI visibility data">

.. only:: html

  .. image:: /generated/gallery/images/thumb/sphx_glr_rhessi_thumb.png
    :alt:

  :ref:`sphx_glr_generated_gallery_rhessi.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">RHESSI Visibility Imaging</div>
    </div>


.. thumbnail-parent-div-close

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /generated/gallery/stix
   /generated/gallery/rhessi


.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-gallery

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download all examples in Python source code: gallery_python.zip </generated/gallery/gallery_python.zip>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download all examples in Jupyter notebooks: gallery_jupyter.zip </generated/gallery/gallery_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
